@@ -2,9 +2,9 @@
 #'
 #' print.StepReg prints to console the from an object of class StepReg
 #'
-#' @param x each dataframe from outputlist
+#' @param x StepReg object
 #' 
-#' @param ... further paramters
+#' @param ... further parameters
 #'
 #' @return formatted dataframe
 #' 
@@ -16,26 +16,26 @@
 #' 
 #' @export
 #' 
-
-print.StepReg <- function(x,  ...){
+print.StepReg <- function(x, ...){
+  Sys.setlocale("LC_CTYPE", "en_US.UTF-8")
+  x <- x[!names(x) %in% c("Detail_selection_summary", "Vote_df")]
+  
   for(i in 1:length(x)){
     y <- x[[i]]
     yName <- names(x)[i]
     if(is.data.frame(y)){
-      outputStepReg(y, text=paste0("Table ", i, ". ", yName))
-      #outputStepReg(y, text=c(yName))
+      addLines(y, text=paste0("Table ", i, ". ", yName))
     }else if(is.list(y)){
       for(j in 1:length(y)){
         ySubName <- paste(yName, "for", names(y)[j], sep=" ")
         suby <- y[[j]]
-        outputStepReg(suby, text=paste0("Table ", i+j-1, ". ", ySubName))
-        #outputStepReg(suby, text=c(ySubName))
+        addLines(suby, text=paste0("Table ", i+j-1, ". ", ySubName))
       }
     }
   }
 }
 
-outputStepReg <- function(x, text){
+addLines <- function(x, text){
   x %>% mutate_if(is.factor,  as.character) -> x
   if(nrow(x)==1){
     dfLen <- sapply(x, nchar)
@@ -51,13 +51,10 @@ outputStepReg <- function(x, text){
   list(x, lengths, side) %>% pmap_dfc(str_pad) -> dataFrame
   cat(format(text,  width = sum(lengths),  justify = "left")); cat("\n")
   cat(paste0(rep("\u2017", sum(lengths)), collapse="")); cat("\n")
-  #cat(paste0(rep("‗", sum(lengths)), collapse="")); cat("\n")
   cat(paste0(dfHeader, collapse="")); cat("\n")
   cat(paste0(rep("\u2014", sum(lengths)), collapse="")); cat("\n")
-  #cat(paste0(rep("—", sum(lengths)), collapse="")); cat("\n")
   for(i in 1:nrow(dataFrame)){
     cat(paste0(dataFrame[i, ], collapse=""), "\n")
   }
   cat(paste0(rep("\u2017", sum(lengths)), collapse="")); cat("\n"); cat("\n")
-  #cat(paste0(rep("‗", sum(lengths)), collapse="")); cat("\n"); cat("\n")
 }
\ No newline at end of file
